Documentation
¶
Index ¶
- func PrintVerification(imgRef string, verified []oci.Signature, output string)
- func PrintVerificationHeader(imgRef string, co *cosign.CheckOpts, bundleVerified, fulcioVerified bool)
- func VerifyBlobCmd(ctx context.Context, ko options.KeyOpts, ...) error
- type VerifyAttestationCommand
- type VerifyBlobAttestationCommand
- type VerifyCommand
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PrintVerification ¶
PrintVerification logs details about the verification to stdout
func PrintVerificationHeader ¶
func VerifyBlobCmd ¶
func VerifyBlobCmd(ctx context.Context, ko options.KeyOpts, certRef, certEmail, certIdentity, certOidcIssuer, certChain, sigRef, blobRef, certGithubWorkflowTrigger, certGithubWorkflowSha, certGithubWorkflowName, certGithubWorkflowRepository, certGithubWorkflowRef string, enforceSCT bool) error
nolint
Types ¶
type VerifyAttestationCommand ¶
type VerifyAttestationCommand struct {
options.RegistryOptions
CheckClaims bool
KeyRef string
CertRef string
CertEmail string
CertIdentity string
CertOidcIssuer string
CertGithubWorkflowTrigger string
CertGithubWorkflowSha string
CertGithubWorkflowName string
CertGithubWorkflowRepository string
CertGithubWorkflowRef string
CertChain string
EnforceSCT bool
Sk bool
Slot string
Output string
RekorURL string
PredicateType string
Policies []string
LocalImage bool
NameOptions []name.Option
}
VerifyAttestationCommand verifies a signature on a supplied container image nolint
type VerifyBlobAttestationCommand ¶ added in v1.13.1
type VerifyBlobAttestationCommand struct {
CheckClaims bool
KeyRef string
PredicateType string
SignaturePath string // Path to the signature
}
VerifyBlobAttestationCommand verifies an attestation on a supplied blob nolint
type VerifyCommand ¶
type VerifyCommand struct {
options.RegistryOptions
CheckClaims bool
KeyRef string
CertRef string
CertEmail string
CertIdentity string
CertOidcIssuer string
CertGithubWorkflowTrigger string
CertGithubWorkflowSha string
CertGithubWorkflowName string
CertGithubWorkflowRepository string
CertGithubWorkflowRef string
CertChain string
CertOidcProvider string
EnforceSCT bool
Sk bool
Slot string
Output string
RekorURL string
Attachment string
Annotations sigs.AnnotationsMap
SignatureRef string
HashAlgorithm crypto.Hash
LocalImage bool
NameOptions []name.Option
}
VerifyCommand verifies a signature on a supplied container image nolint
Click to show internal directories.
Click to hide internal directories.